@@ -50,6 +50,19 @@ launcher_generation_checks() {
 		application_type "$application"
 	)
 	if [ -z "$application_type" ]; then
+		# If the type could not be found despite a binary path being set,
+		# this binary could be missing.
+		local application_exe
+		application_exe=$(
+			set_current_package "$package"
+			application_exe "$application"
+		)
+		if [ -n "${application_exe:-}" ]; then
+			if ! launcher_target_presence_check "$package" "$application"; then
+				error_launcher_missing_binary "$application_exe"
+				return 1
+			fi
+		fi
 		error_no_application_type "$application"
 		return 1
 	fi
