@@ -9,6 +9,10 @@ renpy_launcher() {
 	case "$prefix_type" in
 		('none')
 			launcher_headers
+
+			# Set the paths that should be available to the generated launcher
+			launcher_init_paths "$application"
+
 			renpy_launcher_run
 			launcher_exit
 		;;
@@ -41,11 +45,8 @@ renpy_exec_line() {
 	local application
 	application="$1"
 
-	local path_game
-	path_game=$(path_game_data)
-
-	cat <<- EOF
-	renpy "$path_game"
+	cat <<- 'EOF'
+	renpy "$PATH_GAME_DATA"
 	EOF
 }
 
