@@ -36,6 +36,10 @@ archlinux_dependencies_single_command() {
 
 	local package_names
 	case "$required_command" in
+		('7za')
+			package_names='
+			extra/p7zip'
+		;;
 		('corsix-th')
 			package_names='
 			corsix-th'
@@ -48,6 +52,10 @@ archlinux_dependencies_single_command() {
 			package_names='
 			dosbox'
 		;;
+		('godot3-runner')
+			# The Godot 3 runtime is not provided by Arch Linux, not even in the AUR
+			return 0
+		;;
 		('java')
 			package_names='
 			jre8-openjdk'
