@@ -122,9 +122,9 @@ debian_package_build_single() {
 	# unless called with --overwrite.
 	local option_overwrite
 	option_overwrite=$(option_value 'overwrite')
-	if \
-		[ "$option_overwrite" -eq 0 ] \
-		&& [ -e "$generated_package_path" ]
+	if
+		[ "$option_overwrite" -eq 0 ] &&
+		[ -e "$generated_package_path" ]
 	then
 		information_package_already_exists "$package_name"
 		return 0
