@@ -37,6 +37,10 @@ debian_dependencies_single_command() {
 
 	local package_names
 	case "$required_command" in
+		('7za')
+			package_names='
+			7zip | p7zip-full'
+		;;
 		('corsix-th')
 			package_names='
 			corsix-th'
@@ -49,6 +53,10 @@ debian_dependencies_single_command() {
 			package_names='
 			dosbox'
 		;;
+		('godot3-runner')
+			package_names='
+			godot3-runner'
+		;;
 		('java')
 			package_names='
 			default-jre | java-runtime'
