@@ -37,6 +37,10 @@ gentoo_dependencies_single_command() {
 
 	local package_names
 	case "$required_command" in
+		('7za')
+			package_names='
+			app-arch/p7zip'
+		;;
 		('corsix-th')
 			package_names='
 			games-simulation/corsix-th'
@@ -49,6 +53,11 @@ gentoo_dependencies_single_command() {
 			package_names='
 			games-emulation/dosbox'
 		;;
+		('godot3-runner')
+			## TODO: Some version constraint might be required
+			package_names='
+			dev-games/godot'
+		;;
 		('java')
 			package_names='
 			virtual/jre'
